@@ -112,7 +112,6 @@ OC.L10N.register(
     "Personal info" : "Лични данни",
     "Mobile & desktop" : "Мобилни и настолни",
     "Email server" : "Имейл сървър",
-    "Security & setup warnings" : "Предупреждения за сигурността и настройките",
     "Background jobs" : "Фонови процеси",
     "Unlimited" : "Неограничено",
     "Verifying" : "Потвърждаване",
@@ -163,7 +162,6 @@ OC.L10N.register(
     "Save changes" : "Запиши промените",
     "Update to {update}" : "Актуализирай до {update}",
     "Remove" : "Премахване",
-    "Disable" : "Изключване",
     "Featured" : "Препоръчани",
     "This app is supported via your current Nextcloud subscription." : "Това приложение се поддържа чрез текущия ви абонамент за Nextcloud.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Представените приложения са разработени от и в рамките на общността. Те предлагат централна функционалност и са готови за производствена употреба.",
@@ -179,6 +177,8 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n приложения имат налична актуализация ","%n приложения имат налична актуализация"],
     "_Update_::_Update all_" : ["Актуализиране на всички","Актуализиране на всички"],
     "Loading" : "Зареждане",
+    "Type" : "Тип",
+    "Display Name" : "Име за визуализация",
     "Details" : "Подробности",
     "All" : "Всички",
     "Limit app usage to groups" : "Ограничаване използването на приложението от групи",
@@ -273,8 +273,6 @@ OC.L10N.register(
     "Error removing profile picture" : "Грешка при премахване на профилна снимка",
     "Your biography" : "Вашата биография",
     "You are a member of the following groups:" : "Членувате в следните групи:",
-    "You are using <strong>{usage}</strong>" : "Използвате <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Използвате <strong>{usage}</strong> от <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Вашето пълно име",
     "Primary email for password reset and notifications" : "Основен имейл за възстановяване на парола и известия",
     "Email options" : "Опции за имейл",
@@ -373,11 +371,11 @@ OC.L10N.register(
     "About" : "Относно",
     "Full name" : "Име",
     "Additional email" : "Допълнителен имейл",
+    "Fediverse (e.g. Mastodon)" : "Fediverse (напр. Mastodon)",
     "Headline" : "Заглавие",
     "Organisation" : "Организация",
     "Phone number" : "Тел. номер",
     "Role" : "Роля",
-    "Fediverse (e.g. Mastodon)" : "Fediverse (напр. Mastodon)",
     "Website" : "Уеб страница",
     "Profile visibility" : "Видимост на профил",
     "Locale" : "Локален/Местен/",
@@ -391,12 +389,13 @@ OC.L10N.register(
     "Show to everyone" : "Показване на всички",
     "Hide" : "Скриване",
     "Download and enable" : "Сваляне и включване",
+    "Disable" : "Изключване",
     "The app will be downloaded from the App Store" : "Приложението ще бъде изтеглено от App Store",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Приложението не е маркирано като съвместимо с вашата версия на Nextcloud. Можете да инсталирате приложението, но е вероятно да не работи безпроблемно.",
     "Never" : "Никога",
     "An error occurred during the request. Unable to proceed." : "Възникна грешка по време на заявката. Не може да се продължи.",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Приложението е активирано, но трябва да бъде актуализирано. Ще бъдете пренасочени към страницата за актуализация след 5 секунди.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Грешка: Това приложение не може да бъде активирано, защото прави сървъра нестабилен",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Приложението е активирано, но трябва да бъде актуализирано. Ще бъдете пренасочени към страницата за актуализация след 5 секунди.",
     "Do you really want to wipe your data from this device?" : "Наистина ли желаете да изтриете цялата информация от това устройство?",
     "Confirm wipe" : "Потвърди изтриването",
     "Error while wiping the device with the token" : "Грешка при изтриване на устройството с токена",
@@ -422,6 +421,7 @@ OC.L10N.register(
     "SMTP Password" : "SMTP парола",
     "Save" : "Запазване",
     "Test and verify email settings" : "Тествайте и потвърждаване на настройките на имейла",
+    "Security & setup warnings" : "Предупреждения за сигурността и настройките",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Важно е, от гледна точка на сигурност и производителност, всичко да бъде настроено коректно. За тази цел са създадени автоматични проверки. Прегледайте връзките, към документацията (по-долу), за допълнителна информация.",
     "All checks passed." : "Всички проверки са преминати.",
     "There are some errors regarding your setup." : "Открити са грешки, в инсталацията на Nextcloud.",
@@ -432,7 +432,6 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "Причини да използвате Nextcloud във вашата организация",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Разработен от {communityopen}общността на Nextcloud{linkclose}, {githubopen}изходният код{linkclose} е лицензиран под {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Харесайте страницата ни във Facebook",
-    "Follow us on Twitter" : "Следвайте ни в Twitter",
     "Follow us on Mastodon" : "Следвайте ни в Mastodon",
     "Check out our blog" : "Посетете блога ни",
     "Subscribe to our newsletter" : "Абонирайте се за нашия имейл бюлетин",
@@ -462,6 +461,8 @@ OC.L10N.register(
     "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php е регистриран в услуга на webcron за извикване на cron.php на всеки 5 минути през HTTP. Случай на употреба: Много малък екземпляр (1–5 потребители в зависимост от употребата).",
     "The cron.php needs to be executed by the system user \"{user}\"." : "Cron.php трябва да се изпълни от системният потребител \"{user}\".",
     "Enable or disable profile by default for new users." : "Активиране или деактивиране на профила по подразбиране за нови потребители.",
+    "You are using <strong>{usage}</strong>" : "Използвате <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Използвате <strong>{usage}</strong> от <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Additional emails" : "Допълнителни имейли",
     "Enable Profile" : "Активиране на профил",
     "New user" : "Нов потребител",
@@ -484,6 +485,7 @@ OC.L10N.register(
     "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Не е налично, тъй като федерирането е деактивирано за вашия профил, свържете се с вашия системен администратор, ако имате въпроси.",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Не е налично, тъй като публикуването на специфични потребителски данни на сървъра за търсене не е разрешено, свържете се с вашия системен администратор, ако имате въпроси",
     "Show to logged in users only" : "Показване само на влезли потребители",
-    "SMTP Username" : "SMTP потребител"
+    "SMTP Username" : "SMTP потребител",
+    "Follow us on Twitter" : "Следвайте ни в Twitter"
 },
 "nplurals=2; plural=(n != 1);");
